@@ -4,6 +4,7 @@
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
+#undef HAVE_SUNKEYSYM_H
 #undef HAVE_STPCPY
 #undef ENABLE_NLS
 #undef ENABLE_BONOBO
@@ -20,4 +21,5 @@
 #undef GCONF_CONFIG_SOURCE
 #undef INSTALL_GCONF_CONFIG_SOURCE
 #undef HAVE_EXIF
-
+#undef HAVE_OLD_LIBEXIF
+#undef HAVE_LIBJPEG
